/* This file is part of the KDE project
   Copyright (C) 2002 Simon Hausmann <hausmann@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef MESSAGEFACTORY_H
#define MESSAGEFACTORY_H

#include <qmap.h>
#include <qcstring.h>
#include <qmemarray.h>

#include "message.h"
#include "singleton.h"

namespace IRC
{

class MessageFactory : public Singleton<MessageFactory>
{
public:
    typedef QMemArray<uint> ErrorCodeArray;
    typedef Message *( *MessageFactoryFunction )( const Message &body );
    typedef Message::NumericReplyInfo ( *ReplyInfoFunction )();

    struct MessageInfo
    {
        MessageInfo() : createMessage( 0 ), replyInfo( 0 ) {}
        MessageInfo( MessageFactoryFunction _createMessage, ReplyInfoFunction _replyInfo )
            : createMessage( _createMessage ), replyInfo( _replyInfo ) {}

        MessageFactoryFunction createMessage;
        ReplyInfoFunction replyInfo;
    };

    bool registerMessageType( const QCString &typeName,
                              const MessageInfo &info );

    template <class MessageImpl>
    void registerMessageImpl();

    Message *createMessage( const QCString &typeName, const Message &body );
    Message::NumericReplyInfo replyInfo( const QCString &typeName );

    MessageFactory();

private:
    MessageFactory( const MessageFactory &rhs );
    MessageFactory &operator=( const MessageFactory &rhs );

    typedef QMap<QCString, MessageInfo> MessageFactoryMap;

    MessageFactoryMap m_registry;
};

template <class MessageImpl>
void MessageFactory::registerMessageImpl()
{
    struct Factory
    {
        static Message *create( const Message &body ) { return new MessageImpl( body ); }
    };

    registerMessageType( MessageImpl::name(), MessageInfo( Factory::create, MessageImpl::replyInfo ) );
}

};

#endif // MESSAGEFACTORY_H

/* vim: et sw=4 ts=4
 */
