/* This file is part of the KDE project
   Copyright (C) 2002 Simon Hausmann <hausmann@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include "standardmessagefilters.h"
#include "window.h"
#include "frontend.h"

using namespace IRC;

MessageFilter::Result ActionFilter::filterMessage( Message &message, Window *window )
{
    QString text = message.parameters().join( " " );

    PrivmsgMessage privMsg( window->frontend().createPrefixedMessage<PrivmsgMessage>() );
    privMsg.setReceiver( window->channel() );
    privMsg.setAction( text );
    message = privMsg;

    window->handlePrivmsgMessage( privMsg );

    return MessageFilter::ContinueFiltering;
}

MessageFilter::Result PartFilter::filterMessage( Message &message, Window *window )
{
    if ( message.parameters().count() > 0 )
        return MessageFilter::ContinueFiltering;

    if ( window->isPrivateChat() ) {
        window->deleteLater();
        return MessageFilter::DiscardMessage;
        // nothing to send to the server
    }

    PartMessage partMsg;
    partMsg.setChannel( window->channel() );
    message = partMsg;
    return MessageFilter::ContinueFiltering;
}

MessageFilter::Result QueryFilter::filterMessage( Message &message, Window *window )
{
    // make user happy and create an empty new window
    QString nick = message.parameter( 0 );

    // ### make active
    window->frontend().windowForChannel( nick, Frontend::CreateIfNotExisting );

    return MessageFilter::DiscardMessage;
}

MessageFilter::Result QuoteFilter::filterMessage( Message &message, Window * /*window*/ )
{
    QStringList parameters = message.parameters();

    QString type = parameters.front();
    parameters.pop_front();

    message = Message( QString::null, type, parameters );
    return AbortFiltering;
}

MessageFilter::Result TopicFilter::filterMessage( Message &message, Window *window )
{
    QStringList parameters = message.parameters();

    if ( parameters.count() == 0 )
        return MessageFilter::ContinueFiltering;

    TopicMessage msg;

    if ( parameters[ 0 ][ 0 ] == '#' ) {
        msg.setChannel( parameters[ 0 ] );

        parameters.remove( parameters.begin() );
    } else
        msg.setChannel( window->channel() );

    msg.setTopic( parameters.join( " " ) );

    message = msg;
    return MessageFilter::ContinueFiltering;
}

#include "standardmessagefilters.moc"

/* vim: et sw=4 ts=4
 */
